@@ -12,6 +12,8 @@ class PreprocessingUtils(object):
     CATEGORICAL = "categorical"
     CONTINOUS = "continous"
     DISCRETE = "discrete"
+    DATETIME = "datetime"
+    TEXT = "text"
 
     @staticmethod
     def get_type(x):
@@ -21,11 +23,24 @@ class PreprocessingUtils(object):
                     "Please select one column to get its type"
                 )
         col_type = str(x.dtype)
+
         data_type = PreprocessingUtils.CATEGORICAL
         if col_type.startswith("float"):
             data_type = PreprocessingUtils.CONTINOUS
         elif col_type.startswith("int"):
             data_type = PreprocessingUtils.DISCRETE
+        elif col_type.startswith("datetime"):
+            data_type = PreprocessingUtils.DATETIME
+
+        if data_type == PreprocessingUtils.CATEGORICAL:
+            # check maybe this categorical is a text
+            # it is a text, if:
+            # has more than 200 unique values
+            # more than half of rows is unique
+            unique_cnt = len(np.unique(x[~pd.isnull(x)]))
+            if unique_cnt > 200 and unique_cnt > int(0.5 * x.shape[0]):
+                data_type = PreprocessingUtils.TEXT
+
         return data_type
 
     @staticmethod
@@ -33,6 +48,16 @@ class PreprocessingUtils(object):
         x = x_org[~pd.isnull(x_org)]
         return PreprocessingUtils.get_type(x) == PreprocessingUtils.CATEGORICAL
 
+    @staticmethod
+    def is_datetime(x_org):
+        x = x_org[~pd.isnull(x_org)]
+        return PreprocessingUtils.get_type(x) == PreprocessingUtils.DATETIME
+
+    @staticmethod
+    def is_text(x_org):
+        x = x_org[~pd.isnull(x_org)]
+        return PreprocessingUtils.get_type(x) == PreprocessingUtils.TEXT
+
     @staticmethod
     def is_0_1(x_org):
         x = x_org[~pd.isnull(x_org)]
